import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/LakshmanRangisetti/b232f059e860a11cb0bb45cd68dee24c/raw/2ee05f8b420c8404e779bb8491832c90564f2664/gistfile1.txt', // File name
].join('');
const parseRow = (d) => {
  d.bill_length_mm = +d.bill_length_mm;
      d.bill_depth_mm = +d.bill_depth_mm;
      d.flipper_length_mm = +d.flipper_length_mm;
      d.body_mass_g = +d.body_mass_g;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.flipper_length_mm;
    const yValue = (d) => d.body_mass_g;
    const rxValue = (d) => d.bill_length_mm;
    const ryValue = (d) => d.bill_depth_mm;
    const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.body_mass_g);
  const y = yValue((d) => d.bill_length_mm);
  const marker = (d) => {
        	switch(d){
            case 'Adelie': //label names on top
              return 'skyblue';  // colours for each type
            case 'Gentoo':
              return 'lightgreen';
            default:
              return 'orange';
          }
        }
  //values of xand y axis
  const marks = data.map((d) => ({
          x: xValue((d) => d.body_mass_g),
          y: yValue((d) => d.bill_length_mm),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//structure of scatterplot  is defined
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.body_mass_g)
    .yValue((d) => d.bill_length_mm)
    .margin({
      top: 28,
      right: 53,
      bottom: 82,
      left: 88,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//shape of that scattered data 
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'bill_length_mm',
    'bill_depth_mm',
    'flipper_length_mm',
    'body_mass_g',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","violet")
    			.style("font-weight","bold")
    			.style("font-style","italic")
          .text(colorLabel);

   
// display Title 
svg.append("text").attr("x", 350).attr("y", 20).text("Penguin Measurements ScatterPlot").style("font-size", "35px").attr("alignment-baseline","middle").attr('fill','green').style("font-style","italic")
        	.style("text-decoration","underline")

   
// Adding  labels in the legend and its style 
svg.append("text").attr("x", 150).attr("y", 70).text("Adelie").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Gentoo").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Chinstrap").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
    			.attr('fill', 'red')
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("bill_length_mm");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "lightblue")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "lightgreen")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "orange")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
    			.attr('fill','red')
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("bill_length_mm");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
    			.attr('fill','red')
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("bill_depth_mm");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
    			.attr('fill','red')
        	.style("text-anchor", "middle")
    			.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("flipper_length_mm");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.attr('fill','red')
        	.style("text-anchor", "middle")
    			.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("body_mass_g");
    i++;
  }, 5000);// every 5 seconds changes the visualization
};
main();




